static const char *lprint_fr_strings =
"\"copies\" = \"Copies\";\n"
"\"job-state\" = \"État de la tâche\";\n"
"\"job-state.3\" = \"En attente\";\n"
"\"job-state.4\" = \"Retenue\";\n"
"\"job-state.5\" = \"Traitement en cours\";\n"
"\"job-state.6\" = \"Arrêtée\";\n"
"\"job-state.7\" = \"Annulée\";\n"
"\"job-state.8\" = \"Interrompue\";\n"
"\"job-state.9\" = \"Terminée\";\n"
"\"job-state-reasons\" = \"État détaillé de la tâche\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Interrompue par le système.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Tâche annulée par l’utilisateur.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Tâche terminée.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Données sur la tâche insuffisantes.\";\n"
"\"job-state-reasons.job-incoming\" = \"Réception de la tâche.\";\n"
"\"job-state-reasons.job-printing\" = \"Impression de la tâche.\";\n"
"\"job-state-reasons.job-stopped\" = \"Arrêtée.\";\n"
"\"job-state-reasons.none\" = \"Aucun.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Traitement jusqu’au point d’arrêt.\";\n"
"\"media\" = \"Support\";\n"
"\"media-col\" = \"Support\";\n"
"\"media-size\" = \"Dimensions du support\";\n"
"\"media-size-name\" = \"Nom du support\";\n"
"\"media-source\" = \"Source du papier\";\n"
"\"media-source.alternate-roll\" = \"Bobine secondaire\";\n"
"\"media-source.main-roll\" = \"Bobine principale\";\n"
"\"media-top-offset\" = \"Décalage supérieur\";\n"
"\"media-tracking\" = \"Suivi des étiquettes\";\n"
"\"media-tracking.continuous\" = \"Continu\";\n"
"\"media-tracking.mark\" = \"Tache\";\n"
"\"media-tracking.web\" = \"Bouge\";\n"
"\"media-type\" = \"Type de papier\";\n"
"\"media-type.continuous\" = \"Continu\";\n"
"\"media-type.labels\" = \"Étiquettes\";\n"
"\"media-type.labels-continuous\" = \"Étiquettes continues\";\n"
"\"orientation-requested\" = \"Orientation\";\n"
"\"orientation-requested.3\" = \"Portrait\";\n"
"\"orientation-requested.4\" = \"Paysage\";\n"
"\"orientation-requested.5\" = \"Paysage inversé\";\n"
"\"orientation-requested.6\" = \"Portrait inversé\";\n"
"\"orientation-requested.7\" = \"Automatique\";\n"
"\"print-color-mode\" = \"Mode colorimétrique de l’impression\";\n"
"\"print-color-mode.bi-level\" = \"Texte\";\n"
"\"print-color-mode.monochrome\" = \"Monochrome\";\n"
"\"print-content-optimize\" = \"Optimisation de l’impression\";\n"
"\"print-content-optimize.auto\" = \"Automatique\";\n"
"\"print-content-optimize.graphic\" = \"Graphismes\";\n"
"\"print-content-optimize.photo\" = \"Photo\";\n"
"\"print-content-optimize.text\" = \"Texte\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Texte et graphismes\";\n"
"\"print-darkness\" = \"Imprimer l'obscurité\";\n"
"\"print-quality\" = \"Qualité d’impression\";\n"
"\"print-quality.3\" = \"Brouillon\";\n"
"\"print-quality.4\" = \"Normale\";\n"
"\"print-quality.5\" = \"Élevée\";\n"
"\"print-speed\" = \"Vitesse d'impression\";\n"
"\"printer-resolution\" = \"Résolution de l’impression\";\n"
"\"printer-state\" = \"État de l’imprimante\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Processing\";\n"
"\"printer-state.5\" = \"Stopped\";\n"
"\"printer-state-reaosns\" = \"État détaillé de l’imprimante\";\n"
"\"printer-state-reasons.cover-open\" = \"Couverture ouverte.\";\n"
"\"printer-state-reasons.media-empty\" = \"Support épuisé.\";\n"
"\"printer-state-reasons.media-jam\" = \"Bourrage du support.\";\n"
"\"printer-state-reasons.media-low\" = \"Support presque épuisé.\";\n"
"\"printer-state-reasons.media-needed\" = \"Support requis.\";\n"
"\"printer-state-reasons.none\" = \"Aucun.\";\n"
"\"printer-state-reasons.other\" = \"Autre.\";\n"
;
