static const char *lprint_de_strings =
"\"copies\" = \"Number of Copies\";\n"
"\"job-state\" = \"Auftragsstatus\";\n"
"\"job-state.3\" = \"Anstehend\";\n"
"\"job-state.4\" = \"Gehalten\";\n"
"\"job-state.5\" = \"Verarbeiten\";\n"
"\"job-state.6\" = \"Gestoppt\";\n"
"\"job-state.7\" = \"Abgebrochen\";\n"
"\"job-state.8\" = \"Abgebrochen\";\n"
"\"job-state.9\" = \"Abgeschlossen\";\n"
"\"job-state-reasons\" = \"Detaillierter Auftragsstatus\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Vom System abgebrochen.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Auftrag durch den Benutzer abgebrochen.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Auftrag erfolgreich ausgeführt.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Unzureichende Auftragsdaten.\";\n"
"\"job-state-reasons.job-incoming\" = \"Eingehender Auftrag.\";\n"
"\"job-state-reasons.job-printing\" = \"Auftrag wird gedruckt.\";\n"
"\"job-state-reasons.job-stopped\" = \"Druckauftrag gestoppt.\";\n"
"\"job-state-reasons.none\" = \"Ohne.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Verarbeitung zum Stopppunkt.\";\n"
"\"media\" = \"Medien\";\n"
"\"media-col\" = \"Medien\";\n"
"\"media-size\" = \"Medienmaße\";\n"
"\"media-size-name\" = \"Medienname\";\n"
"\"media-source\" = \"Medienquelle\";\n"
"\"media-source.alternate-roll\" = \"Alternative Rolle\";\n"
"\"media-source.main-roll\" = \"Hauptrolle\";\n"
"\"media-top-offset\" = \"Oberer Versatz\";\n"
"\"media-tracking\" = \"Etikettenverfolgung\";\n"
"\"media-tracking.continuous\" = \"Kontinuierlich\";\n"
"\"media-tracking.mark\" = \"Markierung\";\n"
"\"media-tracking.web\" = \"Loch\";\n"
"\"media-type\" = \"Medienart\";\n"
"\"media-type.continuous\" = \"Kontinuierlich\";\n"
"\"media-type.labels\" = \"Etiketten\";\n"
"\"media-type.labels-continuous\" = \"Etiketten Kontinuierlich\";\n"
"\"orientation-requested\" = \"Ausrichtung\";\n"
"\"orientation-requested.3\" = \"Hochformat\";\n"
"\"orientation-requested.4\" = \"Querformat\";\n"
"\"orientation-requested.5\" = \"Querformat umgedreht\";\n"
"\"orientation-requested.6\" = \"Hochformat umgedreht\";\n"
"\"orientation-requested.7\" = \"Automatisch\";\n"
"\"print-color-mode\" = \"Druck-Farbmodus\";\n"
"\"print-color-mode.bi-level\" = \"Text\";\n"
"\"print-color-mode.monochrome\" = \"Einfarbig\";\n"
"\"print-content-optimize\" = \"Druckoptimierung\";\n"
"\"print-content-optimize.auto\" = \"Automatisch\";\n"
"\"print-content-optimize.graphic\" = \"Grafiken\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Text\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Text und Grafiken\";\n"
"\"print-darkness\" = \"Dunkelheit drucken\";\n"
"\"print-quality\" = \"Druckqualität\";\n"
"\"print-quality.3\" = \"Entwurf\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Hoch\";\n"
"\"print-speed\" = \"Druckgeschwindigkeit\";\n"
"\"printer-resolution\" = \"Druckauflösung\";\n"
"\"printer-state\" = \"Druckerstatus\";\n"
"\"printer-state.3\" = \"Inaktiv\";\n"
"\"printer-state.4\" = \"Verarbeiten\";\n"
"\"printer-state.5\" = \"Gestoppt\";\n"
"\"printer-state-reaosns\" = \"Detaillierter Druckerstatus\";\n"
"\"printer-state-reasons.cover-open\" = \"Abdeckung offen.\";\n"
"\"printer-state-reasons.media-empty\" = \"Medien leer.\";\n"
"\"printer-state-reasons.media-jam\" = \"Medienstau.\";\n"
"\"printer-state-reasons.media-low\" = \"Medien niedrig.\";\n"
"\"printer-state-reasons.media-needed\" = \"Medien benötigt.\";\n"
"\"printer-state-reasons.none\" = \"Ohne.\";\n"
"\"printer-state-reasons.other\" = \"Andere.\";\n"
;
