static const char *lprint_it_strings =
"\"copies\" = \"Copie\";\n"
"\"job-state\" = \"Stato stampa\";\n"
"\"job-state.3\" = \"In sospeso\";\n"
"\"job-state.4\" = \"Bloccato\";\n"
"\"job-state.5\" = \"Elaborazione in corso\";\n"
"\"job-state.6\" = \"Interrotta\";\n"
"\"job-state.7\" = \"Annullato\";\n"
"\"job-state.8\" = \"Interrotto\";\n"
"\"job-state.9\" = \"Completato\";\n"
"\"job-state-reasons\" = \"Stato dettagliato stampa\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Interrotto dal sistema.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Stampa annullata da utente.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Stampa completata.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Dati stampa insufficienti.\";\n"
"\"job-state-reasons.job-incoming\" = \"Stampa in entrata.\";\n"
"\"job-state-reasons.job-printing\" = \"Stampa.\";\n"
"\"job-state-reasons.job-stopped\" = \"Interrotta.\";\n"
"\"job-state-reasons.none\" = \"Nessuno.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Punto di interruzione elaborazione.\";\n"
"\"media\" = \"File multimediale\";\n"
"\"media-col\" = \"File multimediale\";\n"
"\"media-size\" = \"Dimensioni file multimediale\";\n"
"\"media-size-name\" = \"Nome supporto\";\n"
"\"media-source\" = \"Sorgente media\";\n"
"\"media-source.alternate-roll\" = \"Secondo rotolo\";\n"
"\"media-source.main-roll\" = \"Rotolo principale\";\n"
"\"media-top-offset\" = \"Offset superiore\";\n"
"\"media-tracking\" = \"Monitoraggio label\";\n"
"\"media-tracking.continuous\" = \"Continuo\";\n"
"\"media-tracking.mark\" = \"Segno\";\n"
"\"media-tracking.web\" = \"Buco\";\n"
"\"media-type\" = \"Tipo media\";\n"
"\"media-type.continuous\" = \"Continuo\";\n"
"\"media-type.labels\" = \"Etichette\";\n"
"\"media-type.labels-continuous\" = \"Etichette continuo\";\n"
"\"orientation-requested\" = \"Orientamento\";\n"
"\"orientation-requested.3\" = \"Verticale\";\n"
"\"orientation-requested.4\" = \"Orizzontale\";\n"
"\"orientation-requested.5\" = \"Inverti orientamento orizzontale\";\n"
"\"orientation-requested.6\" = \"Inverti orientamento verticale\";\n"
"\"orientation-requested.7\" = \"Automatico\";\n"
"\"print-color-mode\" = \"Modalità colore di stampa\";\n"
"\"print-color-mode.bi-level\" = \"Testo\";\n"
"\"print-color-mode.monochrome\" = \"Monocromo\";\n"
"\"print-content-optimize\" = \"Ottimizzazione stampa\";\n"
"\"print-content-optimize.auto\" = \"Automatica\";\n"
"\"print-content-optimize.graphic\" = \"Grafici\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Testo\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Testo e grafica\";\n"
"\"print-darkness\" = \"Stampa l'oscurità\";\n"
"\"print-quality\" = \"Qualità stampa\";\n"
"\"print-quality.3\" = \"Bozza\";\n"
"\"print-quality.4\" = \"Normale\";\n"
"\"print-quality.5\" = \"Alta\";\n"
"\"print-speed\" = \"Velocità di stampa\";\n"
"\"printer-resolution\" = \"Risoluzione stampa\";\n"
"\"printer-state\" = \"Stato stampante\";\n"
"\"printer-state.3\" = \"Bozza\";\n"
"\"printer-state.4\" = \"Normale\";\n"
"\"printer-state.5\" = \"Stopped\";\n"
"\"printer-state-reaosns\" = \"Stato dettagliato stampante\";\n"
"\"printer-state-reasons.cover-open\" = \"Coperchio aperto.\";\n"
"\"printer-state-reasons.media-empty\" = \"File multimediale esaurito.\";\n"
"\"printer-state-reasons.media-jam\" = \"Inceppamento file multimediale.\";\n"
"\"printer-state-reasons.media-low\" = \"Livello file multimediale basso.\";\n"
"\"printer-state-reasons.media-needed\" = \"Necessario file multimediale.\";\n"
"\"printer-state-reasons.none\" = \"Nessuna.\";\n"
"\"printer-state-reasons.other\" = \"Altro.\";\n"
;
