static const char *lprint_es_strings =
"\"copies\" = \"Copias\";\n"
"\"job-state\" = \"Estado de la impresión\";\n"
"\"job-state.3\" = \"Pendiente\";\n"
"\"job-state.4\" = \"Retenida\";\n"
"\"job-state.5\" = \"Procesando\";\n"
"\"job-state.6\" = \"Detenida\";\n"
"\"job-state.7\" = \"Cancelado\";\n"
"\"job-state.8\" = \"Interrumpido\";\n"
"\"job-state.9\" = \"Completada\";\n"
"\"job-state-reasons\" = \"Estado de la impresión detallado\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Interrumpido por el sistema.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Impresión cancelada por el usuario.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Impresión completada correctamente.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Datos de impresión insuficientes.\";\n"
"\"job-state-reasons.job-incoming\" = \"Impresión entrante.\";\n"
"\"job-state-reasons.job-printing\" = \"Imprimiendo tarea.\";\n"
"\"job-state-reasons.job-stopped\" = \"Detenida.\";\n"
"\"job-state-reasons.none\" = \"Ninguna.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Procesando hasta el punto de detención.\";\n"
"\"media\" = \"Papel\";\n"
"\"media-col\" = \"Papel\";\n"
"\"media-size\" = \"Dimensiones del papel\";\n"
"\"media-size-name\" = \"Nombre del soporte\";\n"
"\"media-source\" = \"Fuente de papel\";\n"
"\"media-source.alternate-roll\" = \"Rollo alternativo\";\n"
"\"media-source.main-roll\" = \"Rollo principal\";\n"
"\"media-top-offset\" = \"Desplazamiento superior\";\n"
"\"media-tracking\" = \"Seguimiento de etiquetas\";\n"
"\"media-tracking.continuous\" = \"Continuo\";\n"
"\"media-tracking.mark\" = \"Mancha\";\n"
"\"media-tracking.web\" = \"Agujero\";\n"
"\"media-type\" = \"Tipo de papel\";\n"
"\"media-type.continuous\" = \"Continuo\";\n"
"\"media-type.labels\" = \"Etiquetas\";\n"
"\"media-type.labels-continuous\" = \"Etiquetas continuas\";\n"
"\"orientation-requested\" = \"Orientación\";\n"
"\"orientation-requested.3\" = \"Vertical\";\n"
"\"orientation-requested.4\" = \"Horizontal\";\n"
"\"orientation-requested.5\" = \"Horizontal inversa\";\n"
"\"orientation-requested.6\" = \"Vertical inversa\";\n"
"\"orientation-requested.7\" = \"Automática\";\n"
"\"print-color-mode\" = \"Modo de color de la impresión\";\n"
"\"print-color-mode.bi-level\" = \"Texto\";\n"
"\"print-color-mode.monochrome\" = \"Monocromo\";\n"
"\"print-content-optimize\" = \"Optimización de la impresión\";\n"
"\"print-content-optimize.auto\" = \"Automática\";\n"
"\"print-content-optimize.graphic\" = \"Gráficos\";\n"
"\"print-content-optimize.photo\" = \"Foto\";\n"
"\"print-content-optimize.text\" = \"Texto\";\n"
"\"print-content-optimize.text-and-graphic\" = \"Texto y gráficos\";\n"
"\"print-darkness\" = \"Imprimir oscuridad\";\n"
"\"print-quality\" = \"Calidad de impresión\";\n"
"\"print-quality.3\" = \"Borrador\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Alta\";\n"
"\"print-speed\" = \"Print Speed\";\n"
"\"printer-resolution\" = \"Resolución de la impresión\";\n"
"\"printer-state\" = \"Estado de la impresora\";\n"
"\"printer-state.3\" = \"Inactiva\";\n"
"\"printer-state.4\" = \"Procesando\";\n"
"\"printer-state.5\" = \"Detenida\";\n"
"\"printer-state-reaosns\" = \"Estado de la impresora detallado\";\n"
"\"printer-state-reasons.cover-open\" = \"Tapa abierta.\";\n"
"\"printer-state-reasons.media-empty\" = \"Papel vacío.\";\n"
"\"printer-state-reasons.media-jam\" = \"Atasco de papel.\";\n"
"\"printer-state-reasons.media-low\" = \"Poco papel.\";\n"
"\"printer-state-reasons.media-needed\" = \"Se necesita papel.\";\n"
"\"printer-state-reasons.none\" = \"Ninguna.\";\n"
"\"printer-state-reasons.other\" = \"Otra.\";\n"
;
