static const char *lprint_en_strings =
"\"copies\" = \"Number of Copies\";\n"
"\"job-state\" = \"Job State\";\n"
"\"job-state.3\" = \"Pending\";\n"
"\"job-state.4\" = \"Held\";\n"
"\"job-state.5\" = \"Processing\";\n"
"\"job-state.6\" = \"Stopped\";\n"
"\"job-state.7\" = \"Canceled\";\n"
"\"job-state.8\" = \"Aborted\";\n"
"\"job-state.9\" = \"Completed\";\n"
"\"job-state-reasons\" = \"Job Status\";\n"
"\"job-state-reasons.aborted-by-system\" = \"Aborted.\";\n"
"\"job-state-reasons.job-canceled-by-user\" = \"Canceled.\";\n"
"\"job-state-reasons.job-completed-successfully\" = \"Printed.\";\n"
"\"job-state-reasons.job-data-insufficient\" = \"Waiting for document.\";\n"
"\"job-state-reasons.job-incoming\" = \"Receiving document.\";\n"
"\"job-state-reasons.job-printing\" = \"Printing.\";\n"
"\"job-state-reasons.job-stopped\" = \"Stopped.\";\n"
"\"job-state-reasons.none\" = \"Pending.\";\n"
"\"job-state-reasons.processing-to-stop-point\" = \"Stopping.\";\n"
"\"media\" = \"Media Size\";\n"
"\"media-col\" = \"Media\";\n"
"\"media-size\" = \"Media Size\";\n"
"\"media-size-name\" = \"Media Size\";\n"
"\"media-source\" = \"Roll\";\n"
"\"media-source.alternate-roll\" = \"Alternate Roll\";\n"
"\"media-source.main-roll\" = \"Main Roll\";\n"
"\"media-top-offset\" = \"Top Offset\";\n"
"\"media-tracking\" = \"Label Tracking\";\n"
"\"media-tracking.continuous\" = \"Continuous\";\n"
"\"media-tracking.mark\" = \"Mark\";\n"
"\"media-tracking.web\" = \"Web/Hole\";\n"
"\"media-type\" = \"Media Type\";\n"
"\"media-type.continuous\" = \"Continuous Paper\";\n"
"\"media-type.labels\" = \"Cut Labels\";\n"
"\"media-type.labels-continuous\" = \"Continuous Labels\";\n"
"\"orientation-requested\" = \"Orientation\";\n"
"\"orientation-requested.3\" = \"Portrait\";\n"
"\"orientation-requested.4\" = \"Landscape\";\n"
"\"orientation-requested.5\" = \"Reverse Landscape\";\n"
"\"orientation-requested.6\" = \"Reverse Portrait\";\n"
"\"orientation-requested.7\" = \"Automatic\";\n"
"\"print-color-mode\" = \"Color Mode\";\n"
"\"print-color-mode.bi-level\" = \"Black and White\";\n"
"\"print-color-mode.monochrome\" = \"Grayscale\";\n"
"\"print-content-optimize\" = \"Optimize\";\n"
"\"print-content-optimize.auto\" = \"Automatically\";\n"
"\"print-content-optimize.graphic\" = \"for Graphics\";\n"
"\"print-content-optimize.photo\" = \"for Photographs\";\n"
"\"print-content-optimize.text\" = \"for Text Only\";\n"
"\"print-content-optimize.text-and-graphic\" = \"for Text and Graphics\";\n"
"\"print-darkness\" = \"Print Darkness\";\n"
"\"print-quality\" = \"Print Quality\";\n"
"\"print-quality.3\" = \"Draft\";\n"
"\"print-quality.4\" = \"Normal\";\n"
"\"print-quality.5\" = \"Best\";\n"
"\"print-speed\" = \"Print Speed\";\n"
"\"printer-resolution\" = \"Print Resolution\";\n"
"\"printer-state\" = \"Printer State\";\n"
"\"printer-state.3\" = \"Idle\";\n"
"\"printer-state.4\" = \"Processing\";\n"
"\"printer-state.5\" = \"Stopped\";\n"
"\"printer-state-reaosns\" = \"Printer Status\";\n"
"\"printer-state-reasons.cover-open\" = \"Cover open.\";\n"
"\"printer-state-reasons.media-empty\" = \"Out of paper.\";\n"
"\"printer-state-reasons.media-jam\" = \"Paper jam.\";\n"
"\"printer-state-reasons.media-low\" = \"Replace paper soon.\";\n"
"\"printer-state-reasons.media-needed\" = \"Load paper.\";\n"
"\"printer-state-reasons.none\" = \"Ready.\";\n"
"\"printer-state-reasons.other\" = \"See printer.\";\n"
;
