//
// ZPL driver table for LPrint, a Label Printer Application
//
// Copyright © 2019-2021 by Michael R Sweet.
//
// Licensed under Apache License v2.0.  See the file "LICENSE" for more
// information.
//

{ "zpl_2inch-203dpi-dt",        "Zebra ZPL 2-inch/203dpi/Direct-Thermal",
  "", NULL },
{ "zpl_2inch-203dpi-tt",        "Zebra ZPL 2-inch/203dpi/Thermal-Transfer",
  "", NULL },
{ "zpl_2inch-300dpi-dt",        "Zebra ZPL 2-inch/300dpi/Direct-Thermal",
  "", NULL },
{ "zpl_2inch-300dpi-tt",        "Zebra ZPL 2-inch/300dpi/Thermal-Transfer",
  "", NULL },
{ "zpl_2inch-600dpi-tt",        "Zebra ZPL 2-inch/600dpi/Thermal-Transfer",
  "", NULL },
{ "zpl_4inch-203dpi-dt",        "Zebra ZPL 4-inch/203dpi/Direct-Thermal",
  "", NULL },
{ "zpl_4inch-203dpi-tt",        "Zebra ZPL 4-inch/203dpi/Thermal-Transfer",
  "", NULL },
{ "zpl_4inch-300dpi-dt",        "Zebra ZPL 4-inch/300dpi/Direct-Thermal",
  "", NULL },
{ "zpl_4inch-300dpi-tt",        "Zebra ZPL 4-inch/300dpi/Thermal-Transfer",
  "", NULL },
{ "zpl_4inch-600dpi-tt",        "Zebra ZPL 4-inch/600dpi/Thermal-Transfer",
  "", NULL },
